import { FetchTokenAmountFilter, FetchTokenStrategy, Mint } from '@metaplex-foundation/mpl-essentials';
import { Context, PublicKey, RpcAccount, RpcGetAccountsOptions } from '@metaplex-foundation/umi';
import { Edition, MasterEdition, Metadata, TokenStandard } from './generated';
export type DigitalAsset = {
    publicKey: PublicKey;
    mint: Mint;
    metadata: Metadata;
    edition?: ({
        isOriginal: true;
    } & MasterEdition) | ({
        isOriginal: false;
    } & Edition);
};
export declare function fetchDigitalAsset(context: Pick<Context, 'rpc' | 'serializer' | 'eddsa' | 'programs'>, mint: PublicKey, options?: RpcGetAccountsOptions): Promise<DigitalAsset>;
export declare function fetchDigitalAssetByMetadata(context: Pick<Context, 'rpc' | 'serializer' | 'eddsa' | 'programs'>, metadata: PublicKey, options?: RpcGetAccountsOptions): Promise<DigitalAsset>;
export declare function fetchAllDigitalAsset(context: Pick<Context, 'rpc' | 'serializer' | 'eddsa' | 'programs'>, mints: PublicKey[], options?: RpcGetAccountsOptions): Promise<DigitalAsset[]>;
export declare function fetchAllDigitalAssetByCreator(context: Pick<Context, 'rpc' | 'serializer' | 'eddsa' | 'programs'>, creator: PublicKey, options?: RpcGetAccountsOptions & {
    position?: number;
}): Promise<DigitalAsset[]>;
export declare function fetchAllDigitalAssetByUpdateAuthority(context: Pick<Context, 'rpc' | 'serializer' | 'eddsa' | 'programs'>, updateAuthority: PublicKey, options?: RpcGetAccountsOptions): Promise<DigitalAsset[]>;
export declare function fetchAllDigitalAssetByOwner(context: Pick<Context, 'rpc' | 'serializer' | 'eddsa' | 'programs'>, owner: PublicKey, options?: RpcGetAccountsOptions & {
    tokenStrategy?: FetchTokenStrategy;
    tokenAmountFilter?: FetchTokenAmountFilter;
}): Promise<DigitalAsset[]>;
export declare function fetchAllMetadataByOwner(context: Pick<Context, 'rpc' | 'serializer' | 'eddsa' | 'programs'>, owner: PublicKey, options?: RpcGetAccountsOptions & {
    tokenStrategy?: FetchTokenStrategy;
    tokenAmountFilter?: FetchTokenAmountFilter;
}): Promise<Metadata[]>;
export declare function deserializeDigitalAsset(context: Pick<Context, 'serializer'>, mintAccount: RpcAccount, metadataAccount: RpcAccount, editionAccount?: RpcAccount): DigitalAsset;
export declare const isFungible: (tokenStandard: TokenStandard) => boolean;
export declare const isNonFungible: (tokenStandard: TokenStandard) => boolean;
export declare const isProgrammable: (tokenStandard: TokenStandard) => boolean;
